<?php
defined('ABSPATH') or die;

class TCK_LoadLanguage {

	private $locale, $plugin, $strings, $plugins;

	protected static $instance;

	function __construct() {
		if (empty($this->locale)) {
			$this->locale = apply_filters( 'plugin_locale', get_locale(), 'template-creator-ck' );

			// set the default language
			if ($this->locale == 'en_US') $this->locale = 'default';
		}
		$this->strings = Array();
	}

	public static function getInstance($plugin)
	{
		if (empty(self::$instance)) {
			self::$instance = new TCK_LoadLanguage();
			self::$instance->load($plugin);
		}

		return self::$instance;
	}
	
	function load($plugin, $path = null) {
		if (empty($this->plugins[$plugin])) {
			$this->plugin = $plugin;
			$default_strings = $this->parse('default', $path);
			$default_strings['JYES'] = 'Yes';
			$default_strings['JNO'] = 'No';
			$locale_strings = $this->parse($this->locale, $path);

			if (is_array($default_strings) && is_array($locale_strings))
			{
				// Sort the underlying heap by key values to optimize merging
				ksort($default_strings, SORT_STRING);
				$this->plugins[$plugin] = new stdClass();
				$this->plugins[$plugin]->strings = array_merge($default_strings, $locale_strings);
	
				$this->strings = array_merge($this->strings, $this->plugins[$plugin]->strings);

				return $this->strings;
			}

			return array();
		}

		return $this->strings;
	}
	
	function parse($lang = 'default', $path = null) {
		if (! $path) $path = plugin_dir_path( __FILE__ );
		// $lang = str_replace('_', '-', $lang);
		$dir = str_replace('helpers' , 'languages', $path);
		$filename = $dir . $lang . '/' . $lang . '.' . $this->plugin . '.ini';
		$filename2 = $dir . str_replace('_', '-', $lang) . '/' . str_replace('_', '-', $lang) . '.com_templateck_' . $this->plugin . '.ini';

		if (! file_exists($filename) && ! file_exists($filename2))
		{
			return array();
		}
		$contents = @file_get_contents($filename);
		if (!$contents) $contents = @file_get_contents($filename2);

		$contents = str_replace('_QQ_', '"\""', $contents);
		$strings = @parse_ini_string($contents);

		if (!is_array($strings))
		{
			$strings = array();
		}

		return $strings;
	}

	public function exists($string) {
		if ( isset($this->strings[(string) $string]) ) {
			return true;
		}
		return false;
	}

	public function get($string) {
		if ( $this->exists($string) ) {
			return $this->strings[(string) $string];
		}
		return $string;
	}
}