<?php

/**
 * @name		Template Creator CK
 * @copyright	Copyright (C) since 2011. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		Cedric Keiflin - http://www.template-creator.com - http://www.joomlack.fr
 */
// No direct access
defined('TCK_LOADED') or die;

/**
 * Templateck helper.
 */
class TemplateckHelper {
	/**
	* Check updates for the component, module, or plugins
	*/
	public static function check_update() {
		error_reporting(0); // to avoid errors to be triggered
		if ( version_compare(self::get_latest_version(), self::get_current_version() ) > 0 ) {
			$update_status = '<span class="badge-alertck">' . TCK_Text::_('CK_UPDATE_NOTIFICATION') . '</span>';
		} else {
			$update_status = '';
		}

		echo $update_status;
		set_transient( 'templatecreatorck_udpate_status', $update_status, 3600 );
		die;
	}

	/**
	 * Check if a new version is available
	 * 
	 * @return false, or the latest version
	 */
	public static function get_latest_version() {
		$release_notes = self::get_release_notes();
		$latest_version = false;
		if ($release_notes !== false) {
			$test_version = preg_match('/\*(.*?)\n/', $release_notes, $results);
			$latest_version = trim($results[1]);
//			$is_uptodate = version_compare($latest_version, self::get_current_version() ) > 0 ? false : true;
		}

		return $latest_version;
	}
	
	/*
	 * Get a variable from the manifest file (actually, from the manifest cache).
	 * 
	 * @return the current version
	 */
	public static function get_current_version() {
		$manifest = get_plugin_data( TEMPLATECREATORCK_PATH . '/template-creator-ck.php', $markup = true, $translate = true );
		return $manifest['Version'];
	}

	/**
	 * Get the release notes content
	 * 
	 * @return false or the file content
	 */
	public static function get_release_notes() {
		$url = 'http://www.template-creator.com/tck_wp_update.txt';
		return @file_get_contents($url);
	}
	
	/**
	 * Check if you have the latest version
	 * 
	 * @return boolean, true if outdated
	 */
	public static function is_outdated() {
		return version_compare(self::get_latest_version(), self::get_current_version() ) > 0;
	}

	/**
	 * Test if there is already a unit, else add the px
	 *
	 * @param string $value
	 * @return string
	 */
	public static function testUnit($value, $defaultunit = "px") {

		if ((stristr($value, 'px')) OR (stristr($value, 'em')) OR (stristr($value, '%')) OR $value == 'auto')
			return $value;

		return $value . $defaultunit;
	}

	/**
	 * Check the token for security reason
	 * @return boolean
	 */
	public static function checkAjaxToken() {
		if (! wp_verify_nonce($_REQUEST['cktoken'], 'templatecreatorck')) {
			$msg = TCK_Text::_('CK_INVALID_TOKEN');
			echo '{"status": "0", "message": "' . $msg . '"}';
			exit();
		}
		return true;
	}

	/*
	 * Load the JS and CSS files needed to use CKBox
	 *
	 * Return void
	 */
	public static function loadCkbox() {
		?>
		<link rel="stylesheet" href="<?php echo TEMPLATECREATORCK_MEDIA_URI ?>/assets/ckbox.css" type="text/css" />
		<script type="text/javascript" src="<?php echo TEMPLATECREATORCK_MEDIA_URI ?>/assets/ckbox.js" type="text/css"></script>
		<?php
	}

	/*
	 * Load the JS and CSS files needed to use CKBox
	 *
	 * Return void
	 */
	public static function loadCKFramework() {
		$doc = JFactory::getDocument();
		$doc->addScript(JUri::root(true) . '/media/jui/js/jquery.min.js');
		$doc->addStyleSheet(TEMPLATECREATORCK_MEDIA_URI . '/assets/ckframework.css');
	}

	/*
	 * Load the JS and CSS files needed to use CKBox
	 *
	 * Return void
	 */
	public static function loadInlineCKFramework() {
	?>
		<link rel="stylesheet" href="<?php echo TEMPLATECREATORCK_MEDIA_URI ?>/assets/ckframework.css" type="text/css" />
	<?php
	}

	/*
	 * Replace the variables to store the file
	 * 
	 * @return string, the json encoded item
	 */
	public static function getExportFile($item) {
		$item->htmlcode = str_replace(TEMPLATECREATORCK_URI_ROOT, "|URIROOT|", $item->htmlcode);
		$exportfiletext = json_encode($item);

		return $exportfiletext;
	}

	/**
	 * Give the file directly for download in the browser
	 * 
	 * @param type $file
	 */
	public static function pushFileForDownload($filepath) {
		$filepath = TEMPLATECREATORCK_PATH . $filepath;
		$filename = basename($filepath);
		header('Content-type: application/zip');
		header("Content-Disposition: attachment; filename=$filename");                             
		header("Content-Length: " . filesize($filepath));

		readfile($filepath);

		exit();
	}

	/**
	 * Utility function to map an array to a stdClass object.
	 *
	 * @param   array    $array      The array to map.
	 * @param   string   $class      Name of the class to create
	 * @param   boolean  $recursive  Convert also any array inside the main array
	 *
	 * @return  object
	 *
	 * @since   1.0
	 */
	public static function toObject(array $array, $class = 'stdClass', $recursive = true)
	{
		$obj = new $class;

		foreach ($array as $k => $v)
		{
			if ($recursive && is_array($v))
			{
				$obj->$k = static::toObject($v, $class);
			}
			else
			{
				$obj->$k = $v;
			}
		}

		return $obj;
	}

	public static function getToken($name = 'templatecreatorck') {
		return wp_create_nonce($name);
	}

	public static function checkToken() {
		if (! wp_verify_nonce($_REQUEST['_wpnonce'], 'templatecreatorck_save')) {
			$msg = TCK_Text::_('CK_INVALID_TOKEN');
			exit($msg);
		}
	}

	public static function redirect($url, $msg = '', $type = '') {
		if ($msg) {
			self::enqueueMessage($msg, $type);
		}
		// If the headers have been sent, then we cannot send an additional location header
		// so we will output a javascript redirect statement.
		if (headers_sent())
		{
			echo "<script>document.location.href='" . str_replace("'", '&apos;', $url) . "';</script>\n";
		}
		else
		{
			// All other browsers, use the more efficient HTTP header method
			header('HTTP/1.1 303 See other');
			header('Location: ' . $url);
			header('Content-Type: text/html; charset=UTF-8');
		}
	}

	public static function enqueueMessage($msg, $type = 'message') {
		// add the information message
		$transient[] = Array("text" => TCK_Text::_($msg), "type" => $type);
		set_transient( 'templatecreatorck_message', $transient, 60 );
	}

	public static function displayMessages() {
		// manage the information messages
		if ($messages = get_transient( 'templatecreatorck_message' )) {
			if (count($messages)) {
				foreach ($messages as $message) {
					if (is_array($message)) {
						$type = $message["type"] == 'error' ? 'danger': ($message["type"] == 'success' ? 'success' : 'info');
						echo '<div class="ckalert ckalert-' . $type . '">' . $message["text"] . '<div class="ckclose" onclick="jQuery(this).parent().remove()">×</div></div>';
					} else {
						echo '<div class="ckalert ckalert-warning">' . $message . '<div class="ckclose" onclick="jQuery(this).parent().remove()">×</div></div>';
					}
				}
			}
			delete_transient( 'templatecreatorck_message' );
		}
	}
}
