<?php

/**
 * @name		Template Creator CK 3
 * @package		com_templateck
 * @copyright	Copyright (C) 2013. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		Cedric Keiflin - http://www.template-creator.com - http://www.joomlack.fr
 */
// No direct access to this file
defined('ABSPATH') or die('Restricted access');

class TemplateckModelFont extends stdClass {

	/**
	 * path to the fonts foler
	 *
	 * @var string
	 */
	var $_path;

	/**
	 * Theme object
	 *
	 * @var object
	 */
	var $_data;

	/**
	 * Constructor that retrieves the name from the request
	 *
	 * @access	public
	 * @return	void
	 */
	function __construct() {
		// parent::__construct();

		$this->_path = plugins_url() . '/template-creator-ck/fonts';
		$this->_data = null;
	}

	function getFont($id) {
		if ($id == 0) return false;
		global $wpdb;
		$query = 'SELECT * FROM '. $wpdb->prefix . 'templateck_fonts WHERE id=' . (int)$id;
		$font = $wpdb->get_row($query, OBJECT);

		return $font;
	}

	function editFont() {
		$input = new TCK_Input();
		$font = $this->getFont($input->get('id', 0, 'int'));
		if (! $font) return false;

		$data = new stdClass();
		$data->id = $font->id;;
		$data->name = $input->get('name', $font->name, 'string');
		$data->fontfamilies = $font->fontfamilies;
		$data->styles = $font->styles;
		$data->subset = $input->get('subset', $font->subset, 'string');
		$data->alternatives = $input->get('alternatives', $font->alternatives, 'string');

		return $this->store($data);
	}

	/**
	 * Method to store a record
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function store($data) {
		$id = isset($data->id) ? $data->id : 0;
		$isNew = $id == 0 ? true : false;
		// bind the data
		$ck_post = array(
			'ID' => $id,
			'name' => sanitize_text_field($data->name),
			'styles' => $data->styles,
			'fontfamilies' => $data->fontfamilies,
			'published' => '1',
			'subset' => sanitize_text_field($data->subset),
			'alternatives' => sanitize_text_field($data->alternatives)
		);
		// format the data
		$format = array( 
					'%d',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s'
					);

		// save the post into the database
		global $wpdb;
		$table = $wpdb->prefix . 'templateck_fonts';
		if ($isNew) {
			$save = $wpdb->insert( $table, $ck_post, $format );
		} else {
			$where = array( 'id' => $id );
			$save = $wpdb->update( $table, $ck_post, $where, $format );
		}

		// $ck_post_id = $wpdb->insert_id;

		// if (! $ck_post_id) return false;

		return (bool) $save;
	}

	/**
	 * Method to install a font squirrel
	 *
	 * @access	public
	 * @return	true on success
	 */
	function installFontsquirrel() {
		$input = new TCK_Input();

		if (is_array($file = $input->files->get('fontsquirrel_file', '', 'array'))) {

			// include file and zip archive libraries
			include_once TCK_PATH_COMPONENT . '/helpers/zip.php';

			//Clean up filename to get rid of strange characters like spaces etc
			$filename = TCK_File::makeSafe($file['name']);

			// declare some variables
//			$tck_path_root = WP_PLUGIN_DIR . '/template-creator-ck/';
			$gabarit_folder_name = TCK_File::stripext($file['name']);
			$dest_extracted_zip_folder = TCK_PATH_COMPONENT . '/fonts/' . $gabarit_folder_name;

			// check if the theme already exists
			if (TCK_Folder::exists($dest_extracted_zip_folder)) {
				$msg[] = Array("text" => TCK_Text::_('CK_INSTALL_FONT_ALREADY_EXISTS'), "type" => 'error');
				// add the information message
				set_transient( 'templatecreatorck_message', $msg, 60 );

				return false;
			}

			//Set up the source and destination of the file
			// $src = $file['tmp_name'];

			//First check if the file has the right extension, we need jpg only
			if (strtolower(TCK_File::getExt($filename)) != 'zip') {
				$msg[] = Array("text" => TCK_Text::_('CK_INSTALL_FONT_MUST_BE_ZIP'), "type" => 'error');
				// add the information message
				set_transient( 'templatecreatorck_message', $msg, 60 );

				return false;
			}

			// extract the files
			// instanciate ZIP archiver
			$archiver = new CKArchiveZip();
//			$tck_path_root = WP_PLUGIN_DIR . '/template-creator-ck/';
			// extract archive
			
			// $template_folder_name = str_replace('_gabarit', '', $gabarit_folder_name);
			
			if (!$isSuccess = $archiver->extract($file['tmp_name'], $dest_extracted_zip_folder, $options = array())) {
				$msg[] = Array("text" => TCK_Text::_('CK_INSTALL_FONT_EXTRACT_ERROR'), "type" => 'error');
				// add the information message
				set_transient( 'templatecreatorck_message', $msg, 60 );

				return false;
			}

			// get the content of the file styles.css
			if (!$stylescontent = TCK_File::read($dest_extracted_zip_folder . '/stylesheet.css')) {
				// delete the folder
				if (!TCK_Folder::delete($dest_extracted_zip_folder)) {
					$msg[] = Array("text" => TCK_Text::_('CK_ERROR_DELETING_FONT'), "type" => 'error');
					// add the information message
					set_transient( 'templatecreatorck_message', $msg, 60 );

					return false;
				}

				$msg[] = Array("text" => TCK_Text::_('CK_GET_STYLESCONTENT_FAILED'), "type" => 'error');
				// add the information message
				set_transient( 'templatecreatorck_message', $msg, 60 );

				return false;
			}

			$regex = "#font-family: '(.*?)';#s"; // masque de recherche
			preg_match_all($regex, $stylescontent, $fontfamilies);
			foreach ($fontfamilies[1] as $fontfamily) {
				$stylescontent = str_replace($fontfamily, strtolower($fontfamily), $stylescontent);
			}

			$alternatives = $input->get('sqfontalternatives', '', 'string');

			$data = new stdClass();
			$data->name = TCK_File::stripExt($filename);
			$data->fontfamilies = strtolower(implode(",", $fontfamilies[1]));
			$data->styles = $stylescontent;
			$data->subset = '';
			$data->alternatives = $alternatives;

			// store in db
			$check = $this->store($data);
//			$check = $this->store(TCK_File::stripExt($filename), $stylescontent, strtolower(implode(",", $fontfamilies[1])));
			return $check;
		}
		return false;
	}

	/**
	 * Method to install a font google
	 *
	 * @access	public
	 * @return	true on success
	 */
	function installFontgoogle() {
		$input = new TCK_Input();
		$fonturl = $input->get('googlefonturl', '', 'string');
		$subset = $input->get('googlefontsubset', '', 'string');
		$alternatives = $input->get('googlefontalternatives', '', 'string');
		if (! $fonturl) return false;
		$fontfamily = str_replace('https://fonts.googleapis.com/css?family=', '', $fonturl);
		$fontfamily = str_replace('http://fonts.googleapis.com/css?family=', '', $fontfamily);
		$fontfamily = str_replace('//fonts.googleapis.com/css?family=', '', $fontfamily);
		$fontname = str_replace('+', ' ', $fontfamily);
		$fontname = preg_replace('#(.*?):(.*)#s', '$1', $fontname);
//		$fontfamilies = $fontname;
		$stylescontent = "@import url(" . $fonturl . ");\n";
		$data = new stdClass();
		$data->name = $fontname;
		$data->fontfamilies = $fontname;
		$data->styles = $stylescontent;
		$data->subset = $subset;
		$data->alternatives = $alternatives;
		
		return $this->store($data);
//		return $this->store($fontname, $stylescontent, $fontname);
	}

}
