<?php

/**
 * @name		Template Creator CK 3
 * @package		com_templateck
 * @copyright	Copyright (C) 2013. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		Cedric Keiflin - http://www.template-creator.com - http://www.joomlack.fr
 */
// No direct access to this file
defined('ABSPATH') or die('Restricted access');

class TemplateckModelUpdate extends stdClass {

	var $_url;

	var $_path;

	/**
	 * Constructor that retrieves the name from the request
	 *
	 * @access	public
	 * @return	void
	 */
	function __construct() {
		$this->_url = plugins_url() . '/template-creator-ck';
		$this->_path = WP_PLUGIN_DIR . '/template-creator-ck';
	}

	/**
	 * Method to install a font squirrel
	 *
	 * @access	public
	 * @return	true on success
	 */
	function update_tck() {
		include_once $this->_path . '/helpers/zip.php';

		$archive = $_FILES['file_update']['tmp_name'];
		$destination = $this->_path . '/update';

		// erase all datas in the update folder
		TCK_Folder::delete($destination);

		// create ZIP archiver
		$archiver = new CKArchiveZip();

		// extract Archive
		$isSuccess = $archiver->extract($archive, $destination);

		if (! $isSuccess) {
			echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_ARCHIVE_EXTRACTED_ERROR') . '</p>';
			return false;
		}

		// copy files
		if (! $this->copy_files()) {
			echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_COPY_FILES_ERROR') . '</p>';
			return false;
		}

		// clean update folder
		if (! $this->clean_folder()) {
			echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_CLEAN_FOLDER_ERROR') . '</p>';
			return false;
		}

		return true;
	}

	private function copy_files() {
		// make that the path are written the same
		$update_path = str_replace('\\', '/', $this->_path . '/update');

		$files = TCK_Folder::files($update_path, false, true, true);
		if (! count($files) ) {
			echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_NO_FILE_ERROR') . '</p>';
			return false;
		}

		

		// create the missing folders
		$folderstocopy = TCK_Folder::folders($update_path, '.', true, true);
		foreach ($folderstocopy as $foldertocopy) {
			$foldertocopy = str_replace('\\', '/', $foldertocopy);
			$foldername = str_replace($update_path, '', $foldertocopy);
			$folderdest = $this->_path;
			if (!TCK_Folder::exists($folderdest)) {
				if (! TCK_Folder::create($folderdest)) {
					echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_ERROR_CREATING_FOLDER') . ' : ' . $folderdest . '</p>';
				}
			}
		}

		// copy all files
		$filestocopy = TCK_Folder::files($update_path, '.', true, true);
		$success_copy = true;
		foreach ($filestocopy as $filetocopy) {
			// make that the path are written the same
			$filetocopy = str_replace('\\', '/', $filetocopy);
			$filename = str_replace($update_path, '', $filetocopy);
			$filedest = $this->_path . str_replace('template-creator-ck/', '', $filename);

			if (!TCK_File::copy($filetocopy, $filedest)) {
				$msg2 = '<p class="errorck">' . TCK_Text::_('CK_ERROR_CREATING_COPY') . ' : ' . $filename . '</p>';
				clearstatcache(null, $filedest);
				// check if the file permissions can be read
				if (file_exists($filedest) && @fileperms($filedest)) {
					$fileperms = fileperms($filedest);
					$filerights = decoct( $fileperms & 0777 );
					if ((int)$filerights < 644) {
						// change the file permissions
						if (chmod($filedest,0644)) {
							$msg2 .= '<p class="errorck" style="font-weight:bold;color: orange;">' . TCK_Text::_('CK_FILE_RIGHTS_CHANGED_TO') . ' : 0644</p>';
							if (TCK_File::copy($filetocopy, $filedest)) {
								$msg2 .= '<p class="successck"  style="font-weight:bold;">Second try : ' . TCK_Text::_('CK_SUCCESS_CREATING_COPY') . ' : ' . $filename . '</p>';
							} else {
								$msg2 .= '<p class="errorck">Second try : ' . TCK_Text::_('CK_ERROR_CREATING_COPY') . ' : ' . $filename . '</p>';
								$success_copy = false;
							}
						} else {
							$msg2 .= '<p class="errorck">Second try : ' . TCK_Text::_('CK_ERROR_CHMODING_FILE') . ' : ' . $filename . '</p>';
							$success_copy = false;
						}
					}
				} else {
					$msg2 .= '<p class="errorck">Second try : ' . TCK_Text::_('CK_ERROR_CHECKING_FILEPERMS') . ' : ' . $filename . '</p>';
					$success_copy = false;
				}
				echo $msg2;
			}
		}

		if (! $success_copy) {
			// echo '<p class="errorck" style="Font-size:14px;font-weight:bold;">' . TCK_Text::_('CK_ERROR_CREATING_COPY_FILES') . '</p>';
			return false;
		}
		
		return true;
	}
	
	private function clean_folder() {
		if (! TCK_Folder::delete($this->_path . '/update')) {
			echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_FOLDER_DELETE_ERROR') . '</p>';
			return false;
		}

		if (! TCK_Folder::create($this->_path . '/update')) {
			echo '<p class="errorck">' . TCK_Text::_('CK_UPDATE_FOLDER_CREATE_ERROR') . '</p>';
			return false;
		}

		return true;
	}

}
