<?php
/**
 * Plugin Name: Template Creator CK
 * Plugin URI: http://www.template-creator.com
 * Description: Template Creator CK is a tool to construct your own theme.
 * Version: 2.0.0
 * Author: Cédric KEIFLIN
 * Author URI: https://www.template-creator.com/
 * License: GPL2
 * Text Domain: template-creator-ck
 * Domain Path: /languages
 */

// namespace Templatecreatorck;

defined('ABSPATH') or die;
define('TEMPLATECREATORCK_PLATFORM', 'wordpress');
define('TEMPLATECREATORCK_PATH', dirname(__FILE__));
define('TEMPLATECREATORCK_PROJECTS_PATH', TEMPLATECREATORCK_PATH . '/projects');
define('TEMPLATECREATORCK_ADMIN_URL', admin_url('', 'relative') . 'admin.php?page=templatecreatorck_edit');
define('TEMPLATECREATORCK_ADMIN_GENERAL_URL', admin_url('', 'relative') . 'admin.php?page=templatecreatorck_general');
define('TEMPLATECREATORCK_MEDIA_URI', plugins_url('', __FILE__));
define('TEMPLATECREATORCK_MEDIA_URL', plugins_url('', __FILE__));
define('TEMPLATECREATORCK_PLUGIN_URL', TEMPLATECREATORCK_MEDIA_URL);
define('TEMPLATECREATORCK_TEMPLATES_PATH', ABSPATH . '/wp-content/themes');
define('TEMPLATECREATORCK_SITE_ROOT', ABSPATH);
define('TEMPLATECREATORCK_URI_ROOT', site_url());
define('TEMPLATECREATORCK_URI_BASE', admin_url('', 'relative'));

// set browser cache to 0 to refresh and show the real page 
header("Cache-Control: no-cache, no-store, must-revalidate");
header("Pragma: no-cache");
header("Expires: 0");

class Templatecreatorck {

	private static $instance;

	private $input;

	static function getInstance() { 
		if (!isset(self::$instance))
		{
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Create menu links in the admin
	 */
	public function admin_menu() {
		$update_status = get_transient('templatecreatorck_udpate_status') ? get_transient('templatecreatorck_udpate_status') : '';
		add_menu_page('Template Creator CK', 'Template Creator CK', 'edit_plugins', 'templatecreatorck_general', array($this, 'render_general'), TEMPLATECREATORCK_PLUGIN_URL . '/images/admin_menu.png');
		add_submenu_page('templatecreatorck_general', __('Template Creator CK'), __('All Themes'), 'edit_plugins', 'templatecreatorck_general', array($this, 'render_general'));
		add_submenu_page('templatecreatorck_general', __('Template Creator CK'), __('All Fonts'), 'edit_plugins', 'templatecreatorck_fonts', array($this, 'render_fonts'));
		add_submenu_page('templatecreatorck_general', __('Template Creator CK'), __('Help'), 'edit_plugins', 'templatecreatorck_help', array($this, 'render_help'));
		add_submenu_page('templatecreatorck_general', __('Template Creator CK'), __('About').'<span class="templateckchecking">'.$update_status.'</span>', 'edit_plugins', 'templatecreatorck_about', array($this, 'render_about'));
		add_submenu_page('templatecreatorck_general', __('Edit'), __('Add New Template'), 'edit_plugins', 'templatecreatorck_edit', array($this, 'render_edit'));
	}

	public function render_page($view, $layout = 'default') {
		define('TCK_LOADED', 1);

		// include the classes
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckfilterinput.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckinput.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckpath.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckfile.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckfolder.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckloadlanguage.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/cktext.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/helper.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckcreator.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckinterface.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ckstyles.php';
		require_once TEMPLATECREATORCK_PATH . '/helpers/ziparchiver.php';
		$this->checkDbIntegrity();

		$this->input = new TCK_Input();
		$tasks = $this->input->get('task', '', 'cmd');
		if ($tasks) {
			$tasks = explode('.', $tasks);
			if (count($tasks) == 2) {
				$controllerName = $tasks[0];
				$controllerClassName = TemplateckController . ucfirst($tasks[0]);
				$task = $tasks[1];
				require_once TEMPLATECREATORCK_PATH . '/controllers/' . $controllerName . '.php';
				$controller = new $controllerClassName();
				$controller->$task();
			} else {
				$task = $tasks[0];
				require_once TEMPLATECREATORCK_PATH . '/controller.php';
				$controller = new TemplateckController();
				$controller->$task();
			}
		}

		// require_once( TEMPLATECREATORCK_PATH . '/models/' . $view . '.php' );
		// load the view
		$layout = $this->input->get('layout', $layout, 'cmd');
		$view = $this->input->get('view', $view, 'cmd');
		require_once TEMPLATECREATORCK_PATH . '/helpers/templateckview.php';
		require_once TEMPLATECREATORCK_PATH . '/views/' . $view . '/view.html.php';
		$className = 'TemplateckView' . ucfirst($view);
		$classInstance = new $className();
		$classInstance->display($layout);
		// require_once(TEMPLATECREATORCK_PATH . '/includes/templatecreatorck_' . $page . '.php');
	}

	function render_general() {
		$this->checkDbIntegrity();
		$this->render_page('templates');
	}

	function render_fonts() {
		$this->checkDbIntegrity();
		$this->render_page('fonts');
	}

	function render_help() {
		$this->render_page('help');
	}

	function render_about() {
		$this->render_page('about');
	}

	function render_edit() {
		$this->render_page('template', 'edit');
	}

	private function checkDbIntegrity() {
		$this->searchColumn('templateck_templates', 'widgets');
		$this->searchColumn('templateck_templates','modules');
		$this->searchColumn('templateck_fonts','subset');
		$this->searchColumn('templateck_fonts','alternatives');
		$this->searchTable('layouts');
	}

	private function searchColumn($tableName, $name) {
		global $wpdb;
		$table = $wpdb->prefix . $tableName;

		// test if the columns not exists
		$query = "SHOW COLUMNS FROM " . $table . " LIKE '" . $name . "'";
		$hasColumn = $wpdb->query($query);

		if (! $hasColumn) {
			// add the SQL field to the main table
			$query = 'ALTER TABLE `' . $table . '` ADD `' . $name . '` text NOT NULL;';
			if (! $wpdb->query($query)) {
				echo '<p class="ckalert ckalert-danger">Error during table ' . $tableName . ' update process with the ' . $name . ' column !</p>';
			} else {
				echo '<p class="ckalert ckalert-success">Table ' . $tableName . ' updated with the ' . $name . ' column !</p>';
			}
		} 
	}

	/**
	 * Look if the table exists, if not then create it
	 * 
	 * @global type $wpdb
	 * @param type $tableName
	 */
	private function searchTable($tableName) {
		global $wpdb;

		// test if the table not exists
		$query = "SHOW TABLES LIKE '" . $wpdb->prefix . "templateck_" . $tableName . "'";
		$tableExists = $wpdb->query($query);

		if (! $tableExists) {
			$query = templatecreatorck_sql_create_table_layouts();
//			// add the SQL field to the main table
//			$query = 'ALTER TABLE `' . $table . '` ADD `' . $name . '` text NOT NULL;';
			if (! $wpdb->query($query)) {
				echo '<p class="ckalert ckalert-danger">Error during table ' . $tableName . ' creation process !</p>';
			} else {
				echo '<p class="ckalert ckalert-success">Table ' . $tableName . ' created with success !</p>';
			}
		} 
	}
}

// get the template creator class
$Templatecreatorck = Templatecreatorck::getInstance();

add_action('admin_menu', array($Templatecreatorck, 'admin_menu'), 20);

// if we go into the edition interface, we redirect and kill
if ( isset($_REQUEST['page']) 
		&& $_REQUEST['page'] === 'templatecreatorck_edit'
		// && substr($this->current_action(), 0, 4) !== 'ajax'
		) {
		add_action('admin_init', 'templatecreatorck_edition_init', 20);
}

function templatecreatorck_edition_init() {
	// get the template creator class
	$Templatecreatorck = Templatecreatorck::getInstance();
	$Templatecreatorck->render_page('template', 'edit');
	die();
}

// to create and manage the database
require_once(TEMPLATECREATORCK_PATH . '/helpers/sql.php');
register_activation_hook( __FILE__, 'templatecreatorck_sql_install' );

/*
 * Check the update for Template Creator
 */
function Templatecreatorck_checkversion() {
	// wp_enqueue_script('jquery');
	$js_checking = '<script type="text/javascript">
			jQuery(document).ready(function (){
				jQuery(\'.templateckchecking\').each(function(i ,el){
					jQuery.ajax({
						type: "POST",
						url: \'' . TEMPLATECREATORCK_ADMIN_URL . '&task=check_update&cktoken=' . wp_create_nonce('templatecreatorck') . '\',
						data: {
	}
					}).done(function(response) {
						response = response.trim();
						if ( response.substring(0,7).toLowerCase() == \'error\' ) {
						} else {
							jQuery(el).empty().append(response);
						}
					}).fail(function() {
					});
				});
			});
			</script>';
			$css_checking='
			<style>
				.badge-alertck {
					background-color: #b94a48;
					border-radius: 4px;
					color: #fff;
					font-size: 9px;
					margin: 2px;
					padding: 3px;
					text-shadow: none;
				}
			</style>';
	echo $js_checking;
	echo $css_checking;
}
// check version
add_action('admin_head', 'Templatecreatorck_checkversion');